@@ -327,7 +327,7 @@ static void menu_off(GtkMenu *menu, PersonalMenuNavigatorPlugin *plugin)
 static void
 popup_menu (GtkWidget *button, PersonalMenuNavigatorPlugin *plugin)
 {
-	if (gtk_toggle_button_get_active(plugin->button))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
 	{
 		gtk_menu_popup (GTK_MENU (plugin->menu),NULL,NULL,(GtkMenuPositionFunc)menu_position,plugin,0,gtk_get_current_event_time());
 		plugin->popped=TRUE;
@@ -347,16 +347,13 @@ static gboolean header_activate(GtkWidget *widget, GdkEventButton *event, gpoint
 static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 {
     GtkWidget  *menu_item;
-    GtkWidget  *label;
     GdkPixbuf  *icon;
     GtkIconTheme *icon_theme;
     GtkWidget   *icon_image;
-    GtkWidget  *hbox;
     gchar* filename;
     gboolean fileExists;
     GKeyFile* keyFile;
     GtkAllocation workarea={0,0,0,0};
-    GtkRequisition req={0,0};
 
     if (GTK_IS_MENU(plugin->menu))
 	gtk_widget_destroy(plugin->menu);
@@ -378,6 +375,9 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
       gchar *colourString;
       gchar *fontString;
       gboolean systemBool;
+      gchar *headerColourString;
+      gchar *headerFontString;
+      gboolean headerSystemBool;
       gboolean layoutBool;
       gsize numEntry;
       GError *error=NULL;
@@ -403,6 +403,13 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 		g_error_free(error);
 		error=NULL;
 	}
+	headerColourString=g_key_file_get_string(keyFile,"config","header font colour",&error);
+	if (error)
+	{
+		headerColourString="000000000000";
+		g_error_free(error);
+		error=NULL;
+	}
 	fontString=g_key_file_get_string(keyFile,"config","font style",&error);
 	if (error)
 	{
@@ -410,6 +417,13 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 		g_error_free(error);
 		error=NULL;
 	}
+	headerFontString=g_key_file_get_string(keyFile,"config","header font style",&error);
+	if (error)
+	{
+		headerFontString="Sans 14";
+		g_error_free(error);
+		error=NULL;
+	}
 	systemBool=g_key_file_get_boolean(keyFile,"config","system style",&error);
 	if (error)
 	{
@@ -417,6 +431,13 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 		g_error_free(error);
 		error=NULL;
 	}
+	headerSystemBool=g_key_file_get_boolean(keyFile,"config","header system style",&error);
+	if (error)
+	{
+		headerSystemBool=TRUE;
+		g_error_free(error);
+		error=NULL;
+	}
 	layoutBool=g_key_file_get_boolean(keyFile,"config","auto layout",&error);
 	if (error)
 	{
@@ -447,7 +468,7 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 			minRows=(workarea.height-64)/(iconSize+2);
 		else
 		{
-			GtkStyle *style=gtk_rc_get_style(plugin);
+			GtkStyle *style=gtk_rc_get_style(GTK_WIDGET(plugin));
 			PangoFontDescription *font=style->font_desc;
 			gint fontSize=pango_font_description_get_size(font);
 			if (!pango_font_description_get_size_is_absolute(font))
@@ -475,11 +496,12 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 	appName=g_key_file_get_string(keyFile,entry,"app name",NULL);
 	iconName=g_key_file_get_string(keyFile,entry,"icon name",NULL);
 	executable=g_key_file_get_string(keyFile,entry,"executable",NULL);
-	if (iconSize!=0)
+
+	if (executable!=NULL && g_strcasecmp(executable,"")!=0)
 	{
-		if (executable!=NULL && g_strcasecmp(executable,"")!=0)
+		menu_item=gtk_image_menu_item_new_with_label(appName);
+		if (iconSize!=0)
 		{
-			menu_item=gtk_image_menu_item_new_with_label(appName);
 			icon_theme = gtk_icon_theme_get_default ();
 			icon=gtk_icon_theme_load_icon(icon_theme,iconName,iconSize,0,NULL);
 			if (icon==NULL)
@@ -490,26 +512,25 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 			icon_image=gtk_image_new_from_pixbuf(icon);
 			g_object_unref(G_OBJECT(icon));
 			gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),icon_image);
-			g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),i);
-		}
-		else
-		{
-			menu_item=gtk_menu_item_new_with_label(appName);
-			gtk_label_set_use_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),TRUE);
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",appName,"</span>",NULL));
-			g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
-			g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
 		}
+		if (!systemBool)
+			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",fontString,"' foreground='#",colourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
+		g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),i);
 	}
 	else
 	{
-		menu_item=gtk_image_menu_item_new_with_label(appName);
-		g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),i);
+		menu_item=gtk_menu_item_new_with_label(appName);
+		gtk_label_set_use_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),TRUE);
+		if (headerSystemBool)
+			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",appName,"</span>",NULL));
+		else
+			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",headerFontString,"' foreground='#",headerColourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
+		g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
+		g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
 	}
 
-	if (!systemBool)
-		gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",fontString,"' foreground='#",colourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
-	gtk_menu_attach(plugin->menu,menu_item,x,x+1,y,y+1);
+
+	gtk_menu_attach(GTK_MENU(plugin->menu),menu_item,x,x+1,y,y+1);
 	y++;
 	if (y>entryPerColumn-1)
 	{
@@ -568,9 +589,9 @@ static gboolean menu_changed(PersonalMenuNavigatorPlugin *plugin)
 	plugin->updateTimeout=0;
 	if (plugin->popped)
 	{
-		gtk_toggle_button_set_active(plugin->button,FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(plugin->button),FALSE);
 		create_menu(plugin);
-		gtk_toggle_button_set_active(plugin->button,TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(plugin->button),TRUE);
 	}
 	else
 	{
@@ -596,7 +617,7 @@ static gboolean key_release(GtkWidget *widget,GdkEventKey *event,PersonalMenuNav
     switch (event->keyval) 
     {
 		case GDK_Escape:
-			menu_off(plugin->menu,plugin);
+			menu_off(GTK_MENU(plugin->menu),plugin);
 			return TRUE;
     }
     return FALSE;
@@ -620,7 +641,7 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   gtk_widget_show_all (button);
 
   gtk_container_add (GTK_CONTAINER (navigator_plugin), button);
-  gtk_widget_show_all (navigator_plugin);
+  gtk_widget_show_all (GTK_WIDGET(navigator_plugin));
 
   navigator_plugin->menu=gtk_menu_new();
   create_menu(navigator_plugin);
